//
//  AquaButton.m
//  aquabutton
//
//  Created by kunii on 11/06/15.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//
#import <QuartzCore/QuartzCore.h>
#import "AquaButton.h"


@implementation AquaButton
@synthesize textLabel, hue;

- (NSArray*)gradientArrayWithHue:(float)hue_ 
                      saturation:(float)saturation 
                      brightness:(float)brightness
{
    CGColorRef halationTop = [UIColor colorWithHue:hue_ 
                                        saturation:saturation * 0.2 
                                        brightness:brightness 
                                             alpha:1].CGColor;
    CGColorRef halationBottom = [UIColor colorWithHue:hue_ 
                                           saturation:saturation * 0.8 
                                           brightness:brightness * 0.8 
                                                alpha:1].CGColor;
    CGColorRef normalTop = [UIColor colorWithHue:hue_ 
                                      saturation:saturation 
                                      brightness:brightness * 0.8 
                                           alpha:1].CGColor;
    CGColorRef normalBottom = [UIColor colorWithHue:hue_ 
                                         saturation:saturation 
                                         brightness:brightness 
                                              alpha:1].CGColor;
    NSMutableArray *colors = [NSArray arrayWithObjects:
                              (id)halationTop, 
                              (id)halationBottom, 
                              (id)normalTop, 
                              (id)normalBottom, nil];
    return colors;
}

- (id)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        internalButton = [CAGradientLayer layer];
        internalButton.frame = self.bounds;
        internalButton.borderWidth = 1;
        internalButton.cornerRadius = self.bounds.size.height / 4.0;
        NSMutableArray *locations = [NSArray arrayWithObjects:
                                     [NSNumber numberWithFloat:0.0],
                                     [NSNumber numberWithFloat:0.5],
                                     [NSNumber numberWithFloat:0.5],
                                     [NSNumber numberWithFloat:1.0],nil];
        [internalButton setLocations:locations];
        [internalButton setColors:[self gradientArrayWithHue:hue saturation:1 brightness:1]];
        [self.layer addSublayer:internalButton];
        textLabel = [[[UILabel alloc] initWithFrame:self.bounds] autorelease];
        textLabel.font = [UIFont boldSystemFontOfSize:18];
        textLabel.textColor = [UIColor whiteColor];
        textLabel.textAlignment = UITextAlignmentCenter;
        textLabel.shadowColor = [UIColor grayColor];
        textLabel.backgroundColor = [UIColor clearColor];
        [self addSubview:textLabel];
    }
    return self;
}

- (void)setEnabled:(BOOL)enabled
{
    [super setEnabled:enabled];
    [internalButton setColors:[self gradientArrayWithHue:hue 
                                              saturation:enabled?1:0.3 
                                              brightness:1]];
    internalButton.borderColor = enabled
        ?([UIColor blackColor].CGColor):([UIColor lightGrayColor].CGColor);
}

- (void)setHighlighted:(BOOL)highlighted
{
    [super setHighlighted:highlighted];
    [internalButton setColors:[self gradientArrayWithHue:hue 
                                              saturation:1 
                                              brightness:highlighted?0.7:1]];    
}
@end
